using skyscraper5.T2MI.Packets;
using skyscraper8.T2MI.Packets;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace skyscraper8.DvbSis
{
    internal class NullSisHandler : SisHandler
    {
        public void OnSisCat(int sourcePid, ushort sourceProgram, SisCatContainer catContainer)
        {
        }

        public void OnSisDsaci(ushort currentDsaGroupId, int versionNumber, byte sectionNumber, byte lastSectionNumber, Stream dsaci)
        {

        }

        public void OnSisEit(int sourcePid, ushort sourceProgram, SisEitContainer eitContainer)
        {

        }

        public void OnSisFti(int relatedPid, _0xF0_FramingTimingInformation fti)
        {
        }

        public void OnSisNit(int sourcePid, ushort sourceProgram, SisNitContainer nitContainer)
        {

        }

        public void OnSisPat(int sourcePid, ushort sourceProgram, SisPatContainer patContainer)
        {
        }

        public void OnSisPmt(int sourcePid, ushort sourceProgram, SisPmtContainer pmtContainer)
        {
        }

        public void OnSisSdt(int sourcePid, ushort sourceProgram, SisSdtContainer sdtContainer)
        {
        }

        public void OnSisTdt(int sourcePid, ushort sourceProgram, SisTdtContainer tdtContainer)
        {

        }

        public void OnSisTimestamp(int pid, _0x20_DvbT2Timestamp t2Timestamp)
        {
        }

        public void OnSisTot(int sourcePid, ushort sourceProgram, SisTotContainer totContainer)
        {
        }
    }
}
